import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { createBackup as universalCreateBackup, deleteBackup as universalDeleteBackup, listBackups as universalListBackups, listRestorations as universalListRestorations, restoreBackup as universalRestoreBackup, restorePartialBackup as universalRestorePartialBackup, } from './data-v2-backup-backups.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/data' };
export function createBackup(httpClient) {
    return () => universalCreateBackup(
    // @ts-ignore
    { httpClient });
}
export function listBackups(httpClient) {
    return (options) => universalListBackups(options, 
    // @ts-ignore
    { httpClient });
}
export function restoreBackup(httpClient) {
    return (backupId) => universalRestoreBackup(backupId, 
    // @ts-ignore
    { httpClient });
}
export function restorePartialBackup(httpClient) {
    return (backupId, restorationCollections) => universalRestorePartialBackup(backupId, restorationCollections, 
    // @ts-ignore
    { httpClient });
}
export function listRestorations(httpClient) {
    return (options) => universalListRestorations(options, 
    // @ts-ignore
    { httpClient });
}
export function deleteBackup(httpClient) {
    return (backupId) => universalDeleteBackup(backupId, 
    // @ts-ignore
    { httpClient });
}
export const onBackupStateChanged = EventDefinition('wix.data.v2.backup_backup_state_changed', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.backup.requestedDate' },
            { path: 'data.backup.startedDate' },
            { path: 'data.backup.finishedDate' },
            { path: 'data.backup.deletedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onBackupDeleted = EventDefinition('wix.data.v2.backup_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'undefined.requestedDate' },
            { path: 'undefined.startedDate' },
            { path: 'undefined.finishedDate' },
            { path: 'undefined.deletedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onBackupRestorationStateChanged = EventDefinition('wix.data.v2.backup_restoration_state_changed', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.restoration.requestedDate' },
            { path: 'data.restoration.startedDate' },
            { path: 'data.restoration.finishedDate' },
            { path: 'data.restoration.backup.requestedDate' },
            { path: 'data.restoration.backup.startedDate' },
            { path: 'data.restoration.backup.finishedDate' },
            { path: 'data.restoration.backup.deletedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export { RestorationStatus, Status, Type, WebhookIdentityType, } from './data-v2-backup-backups.universal.js';
//# sourceMappingURL=data-v2-backup-backups.public.js.map